import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/community_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/product_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/space_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/widgets/community_structure_widget.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/widgets/gradient_canvas_border_widget.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/widgets/sidebar_widget.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/bloc/space_model_bloc.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/models/space_template_model.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/view/space_model_page.dart';
import 'package:syncrow_web/services/space_model_mang_api.dart';

class LoadedSpaceView extends StatelessWidget {
  final List<CommunityModel> communities;
  final CommunityModel? selectedCommunity;
  final SpaceModel? selectedSpace;
  final List<ProductModel>? products;
  final List<SpaceTemplateModel>? spaceModels;
  final bool shouldNavigateToSpaceModelPage;

  const LoadedSpaceView({
    super.key,
    required this.communities,
    this.selectedCommunity,
    this.selectedSpace,
    this.products,
    this.spaceModels,
    required this.shouldNavigateToSpaceModelPage
  });

  @override
  Widget build(BuildContext context) {

    return Stack(
      clipBehavior: Clip.none,
      children: [
        Row(
          children: [
            SidebarWidget(
              communities: communities,
              selectedSpaceUuid:
                  selectedSpace?.uuid ?? selectedCommunity?.uuid ?? '',
            ),
            shouldNavigateToSpaceModelPage
                ? Expanded(
                    child: BlocProvider(
                      create: (context) => SpaceModelBloc(
                        api: SpaceModelManagementApi(),
                        initialSpaceModels: spaceModels ?? [],
                      ),
                      child: SpaceModelPage(
                        products: products,
                      ),
                    ),
                  )
                : CommunityStructureArea(
                    selectedCommunity: selectedCommunity,
                    selectedSpace: selectedSpace,
                    spaces: selectedCommunity?.spaces ?? [],
                    products: products,
                    communities: communities,
                    spaceModels: spaceModels,
                  ),
          ],
        ),
        const GradientCanvasBorderWidget(),
      ],
    );
  }

  SpaceModel? findSpaceByUuid(String? uuid, List<CommunityModel> communities) {
    for (var community in communities) {
      for (var space in community.spaces) {
        if (space.uuid == uuid) return space;
      }
    }
    return null;
  }
}
