import 'package:syncrow_web/pages/spaces_management/all_spaces/model/base_tag.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/product_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/selected_product_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/subspace_model.dart';
import 'package:syncrow_web/pages/spaces_management/all_spaces/model/tag.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/models/subspace_template_model.dart';
import 'package:syncrow_web/pages/spaces_management/space_model/models/tag_model.dart';

class TagHelper {
  static List<TagModel> generateInitialTags({
    List<TagModel>? spaceTagModels,
    List<SubspaceTemplateModel>? subspaces,
  }) {
    final List<TagModel> initialTags = [];

    if (spaceTagModels != null) {
      initialTags.addAll(spaceTagModels);
    }

    if (subspaces != null) {
      for (var subspace in subspaces) {
        if (subspace.tags != null) {
          initialTags.addAll(
            subspace.tags!.map(
              (tag) => tag.copyWith(
                location: subspace.subspaceName,
                internalId: tag.internalId,
                tag: tag.tag,
              ),
            ),
          );
        }
      }
    }

    return initialTags;
  }

 static List<Tag> generateInitialForTags({
    List<Tag>? spaceTags,
    List<SubspaceModel>? subspaces,
  }) {
    final List<Tag> initialTags = [];

    if (spaceTags != null) {
      initialTags.addAll(spaceTags);
    }

    if (subspaces != null) {
      for (var subspace in subspaces) {
        if (subspace.tags != null) {
          initialTags.addAll(
            subspace.tags!.map(
              (tag) => tag.copyWith(
                location: subspace.subspaceName,
                internalId: tag.internalId,
                tag: tag.tag,
              ),
            ),
          );
        }
      }
    }

    return initialTags;
  }

  static Map<ProductModel, int> groupTags(List<BaseTag> tags) {
    final Map<ProductModel, int> groupedTags = {};
    for (var tag in tags) {
      if (tag.product != null) {
        final product = tag.product!;
        groupedTags[product] = (groupedTags[product] ?? 0) + 1;
      }
    }
    return groupedTags;
  }

  static List<SelectedProduct> createInitialSelectedProducts(
      List<TagModel>? tags, List<SubspaceTemplateModel>? subspaces) {
    final Map<ProductModel, int> productCounts = {};

    if (tags != null) {
      for (var tag in tags) {
        if (tag.product != null) {
          productCounts[tag.product!] = (productCounts[tag.product!] ?? 0) + 1;
        }
      }
    }

    if (subspaces != null) {
      for (var subspace in subspaces) {
        if (subspace.tags != null) {
          for (var tag in subspace.tags!) {
            if (tag.product != null) {
              productCounts[tag.product!] =
                  (productCounts[tag.product!] ?? 0) + 1;
            }
          }
        }
      }
    }

    return productCounts.entries
        .map((entry) => SelectedProduct(
              productId: entry.key.uuid,
              count: entry.value,
              productName: entry.key.name ?? 'Unnamed',
              product: entry.key,
            ))
        .toList();
  }

  static List<SelectedProduct> createInitialSelectedProductsForTags(
      List<Tag>? tags, List<SubspaceModel>? subspaces) {
    final Map<ProductModel, int> productCounts = {};

    if (tags != null) {
      for (var tag in tags) {
        if (tag.product != null) {
          productCounts[tag.product!] = (productCounts[tag.product!] ?? 0) + 1;
        }
      }
    }

    if (subspaces != null) {
      for (var subspace in subspaces) {
        if (subspace.tags != null) {
          for (var tag in subspace.tags!) {
            if (tag.product != null) {
              productCounts[tag.product!] =
                  (productCounts[tag.product!] ?? 0) + 1;
            }
          }
        }
      }
    }

    return productCounts.entries
        .map((entry) => SelectedProduct(
              productId: entry.key.uuid,
              count: entry.value,
              productName: entry.key.name ?? 'Unnamed',
              product: entry.key,
            ))
        .toList();
  }
}
